#!/system/bin/sh
#
# Copyright (C) 2021-2022 Matt Yang
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

BASEDIR="$(dirname $(readlink -f "$0"))"
. $BASEDIR/pathinfo.sh
. $BASEDIR/libsysinfo.sh

# $1:error_message
abort() {
    echo "$1"
}

# $1:file_node $2:owner $3:group $4:permission $5:secontext
set_perm() {
    chown $2:$3 $1
    chmod $4 $1
    chcon $5 $1
}

# $1:directory $2:owner $3:group $4:dir_permission $5:file_permission $6:secontext
set_perm_recursive() {
    find $1 -type d 2>/dev/null | while read dir; do
        set_perm $dir $2 $3 $4 $6
    done
    find $1 -type f -o -type l 2>/dev/null | while read file; do
        set_perm $file $2 $3 $5 $6
    done
}

install_uperf() {
    echo "- Finding platform specified config"
    echo "- ro.board.platform=$(getprop ro.board.platform)"
    echo "- ro.product.board=$(getprop ro.product.board)"

    local target
    local cfgname
    target="$(getprop ro.board.platform)"
    cfgname="$(get_config_name $target)"
    if [ "$cfgname" == "unsupported" ]; then
        target="$(getprop ro.product.board)"
        cfgname="$(get_config_name $target)"
    fi

    if [ "$cfgname" == "unsupported" ] || [ ! -f $MODULE_PATH/config/$cfgname.json ]; then
        abort "! Target [$target] not supported."
        abort "ERROR -不支持你的处理器。"
        sh $BASEDIR/uninstall.sh
        exit 1
    fi

    echo "- Uperf config is located at $USER_PATH"
    mkdir -p $USER_PATH
    mv -f $USER_PATH/uperf.json $USER_PATH/uperf.json.bak
    cp -f $MODULE_PATH/config/$cfgname.json $USER_PATH/uperf.json
    [ ! -e "$USER_PATH/perapp_powermode.txt" ] && cp $MODULE_PATH/config/perapp_powermode.txt $USER_PATH/perapp_powermode.txt
    rm -rf $MODULE_PATH/config
    set_perm_recursive $BIN_PATH 0 0 0755 0755 u:object_r:system_file:s0
}

install_sfanalysis() {
    echo "⚠️⚠️⚠️⚠️⚠️⚠️⚠️⚠️⚠️⚠️"
    echo "⚠️ 即将为您安装uperf子模块sfanalysis"
    echo "⚠️ 此模块可能导致部分系统无法正常工作"
    echo "⚠️ 如果您不清楚这是干什么的或者不知道其风险请取消安装！"
    echo "⚠️⚠️⚠️⚠️⚠️⚠️⚠️⚠️⚠️⚠️"
    echo "👍 单击音量上键即可确认安装（我已经了解风险，并且愿意尝试）"
    echo "👎 单击音量下键取消安装sfanalysis（我不想冒险，并且满意现状）"
    key_click=""
    while [ "$key_click" = "" ]; do
        key_click="$(getevent -qlc 1 | awk '{ print $3 }' | grep 'KEY_')"
        sleep 0.2
    done
    case "$key_click" in
        "KEY_VOLUMEUP")
            echo "❗您已确认安装，请稍候"
            echo "❗正在为您安装uperf子模块sfanalysis️"
            echo "❗若不幸出现问题，卡logo界面15秒后手动重启"
            echo "❗即可正常开机"
            magisk --install-module "$MODULE_PATH"/modules/sfanalysis-magisk.zip
            echo "* 已为您安装sfanalysis️❤️"
        ;;
        *)
            echo "❗已为您取消安装sfanalysis"
    esac
    rm -rf "$MODULE_PATH"/modules/sfanalysis-magisk.zip
}

install_ssanalysis() {
    echo "⚠️⚠️⚠️⚠️⚠️⚠️⚠️⚠️⚠️⚠️"
    echo "⚠️ 即将为您安装uperf子模块ssanalysis"
    echo "⚠️ 此模块虽然为可选性，但是可以减少桌面掉帧"
    echo "⚠️ 如果您不清楚这是干什么的或者不知道其风险请取消安装！"
    echo "⚠️⚠️⚠️⚠️⚠️⚠️⚠️⚠️⚠️⚠️"
    echo "👍 单击音量上键即可确认安装（我已经了解ssanalysis模块的作用和风险，并且愿意尝试）"
    echo "👎 单击音量下键取消安装ssanalysis（我不想安装ssanalysis模块，并且满意现状）"
    key_click=""
    while [ "$key_click" = "" ]; do
        key_click="$(getevent -qlc 1 | awk '{ print $3 }' | grep 'KEY_')"
        sleep 0.2
    done
    case "$key_click" in
        "KEY_VOLUMEUP")
            echo "❗您已确认安装，请稍候"
            echo "❗正在为您安装uperf子模块ssanalysis"
            echo "❗若不幸出现问题，卡logo界面15秒后手动重启"
            echo "❗即可正常开机"
            magisk --install-module "$MODULE_PATH"/modules/ssanalysis-magisk.zip
            echo "* 已为您安装ssanalysis❤️"
        ;;
        *)
            echo "❗已为您取消安装ssanalysis"
    esac
    rm -rf "$MODULE_PATH"/modules/ssanalysis-magisk.zip
}


install_gpudriver() {
    echo "⚠️⚠️⚠️⚠️⚠️⚠️⚠️⚠️⚠️⚠️"
    echo "⚠️ 即将为您安装mali gpudriver"
    echo "⚠️ 此模块为可选性，用途呢是我自己一次偶然中发现的"
    echo "刷入这个模块的话貌似可以极大提升低端联发科处理器解码能力"
    echo "经实测4K60可以稳定在58帧还是硬解，4k30基本没有压力"
    echo "⚠️刷入此模块有一定的风险，请在备份好数据后再进行操作"
    echo "⚠️ 如果您不清楚这是干什么的或者不知道其风险请取消安装！"
    echo "⚠️⚠️⚠️⚠️⚠️⚠️⚠️⚠️⚠️"
    echo "👍 单击音量上键即可确认安装（我已经了解风险，并且愿意尝试）"
    echo "👎 单击音量下键取消安装gpudriver（我不想冒险，并且满意现状）"
    key_click=""
    while [ "$key_click" = "" ]; do
        key_click="$(getevent -qlc 1 | awk '{ print $3 }' | grep 'KEY_')"
        sleep 0.2
    done
    case "$key_click" in
        "KEY_VOLUMEUP")
            echo "❗您已确认安装，请稍候"
            echo "❗正在为您安装gpudriver"
            echo "❗若不幸出现问题，可以试试救砖模块（不过我刷这么多次都没有变砖过）"
            magisk --install-module "$MODULE_PATH"/modules/MaliGPUDriver.zip
            echo "* 已为您安装MaliGPUDriver❤️"
        ;;
        *)
            echo "❗已为您取消安装MaliGPUDriver"
    esac
    rm -rf "$MODULE_PATH"/modules/MaliGPUDriver.zip
}

get_value() {
   echo "$(grep -E "^$1=" "$2" | head -n 1 | cut -d= -f2)"
}

fix_module_prop() {
    mkdir -p /data/adb/modules/uperf/
    cp -f "$MODULE_PATH/module.prop" /data/adb/modules/uperf/module.prop
}


unlock_limit(){
if [[ ! -d $MODPATH/system/vendor/etc/perf/ ]];then
  dir=$MODPATH/system/vendor/etc/perf/
  mkdir -p $dir
fi

for i in ` ls /system/vendor/etc/perf/ `
do
  touch $dir/$i 
done
}

echo "* "
echo "* 原模块地址 Uperf https://github.com/yc9559/uperf/"
echo "* Author: Matt Yang @fangzheny"
echo "基于吟惋兮的二改yc修改"
echo "* 请不要破坏Uperf运行环境"
echo "* "
echo "* 模块会附带安装你选择安装的模块"
echo "* "
echo "- 正在为您安装Uperf Game Turbo@fangzheny改"
install_uperf
#unlock_limit
echo "* Uperf Game Turbo安装成功"
install_gpudriver
install_ssanalysis
install_sfanalysis
echo "* 你选择的附加模块已安装（如果有选择安装）"
echo "* 重启即可"
echo "* "
echo "祝体验愉快"
fix_module_prop